@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -38,7 +38,6 @@
 #include <algorithm>
 
 #include "Peer.h"
-#include "PeerStorage.h"
 
 namespace aria2 {
 
@@ -60,17 +59,6 @@ void DHTPeerAnnounceEntry::addPeerAddrEntry(const PeerAddrEntry& entry)
   notifyUpdate();
 }
 
-void DHTPeerAnnounceEntry::clearLocal()
-{
-  _peerStorage.reset();
-}
-
-void DHTPeerAnnounceEntry::setPeerStorage
-(const SharedHandle<PeerStorage>& peerStorage)
-{
-  _peerStorage = peerStorage;
-}
-
 size_t DHTPeerAnnounceEntry::countPeerAddrEntry() const
 {
   return _peerAddrEntries.size();
@@ -95,12 +83,12 @@ public:
 void DHTPeerAnnounceEntry::removeStalePeerAddrEntry(time_t timeout)
 {
   _peerAddrEntries.erase(std::remove_if(_peerAddrEntries.begin(), _peerAddrEntries.end(),
-					FindStaleEntry(timeout)), _peerAddrEntries.end());
+                                        FindStaleEntry(timeout)), _peerAddrEntries.end());
 }
 
 bool DHTPeerAnnounceEntry::empty() const
 {
-  return _peerAddrEntries.empty() && _peerStorage.isNull();
+  return _peerAddrEntries.empty();
 }
 
 void DHTPeerAnnounceEntry::getPeers(std::deque<SharedHandle<Peer> >& peers) const
@@ -110,9 +98,6 @@ void DHTPeerAnnounceEntry::getPeers(std::deque<SharedHandle<Peer> >& peers) cons
     SharedHandle<Peer> peer(new Peer((*i).getIPAddress(), (*i).getPort()));
     peers.push_back(peer);
   }
-  if(!_peerStorage.isNull()) {
-    _peerStorage->getActivePeers(peers);
-  }
 }
 
 void DHTPeerAnnounceEntry::notifyUpdate()
